wallaroo.wallaroo_ml_ops_api_client.models.explainability_create_config_json_body_feature_bounds API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.explainability_create_config_json_body_feature_bounds

View Source

     1from typing import Any, Dict, List, Type, TypeVar, cast
     2
     3import attr
     4
     5T = TypeVar("T", bound="ExplainabilityCreateConfigJsonBodyFeatureBounds")
     6
     7@attr.s(auto_attribs=True)
     8class ExplainabilityCreateConfigJsonBodyFeatureBounds:
     9    """ Calculated feature bounds
    10
    11    """
    12
    13    additional_properties: Dict[str, List[float]] = attr.ib(init=False, factory=dict)
    14
    15
    16    def to_dict(self) -> Dict[str, Any]:
    17
    18        field_dict: Dict[str, Any] = {}
    19        for prop_name, prop in self.additional_properties.items():
    20            field_dict[prop_name] = prop
    21
    22
    23
    24
    25        field_dict.update({
    26        })
    27
    28        return field_dict
    29
    30
    31
    32    @classmethod
    33    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    34        d = src_dict.copy()
    35        explainability_create_config_json_body_feature_bounds = cls(
    36        )
    37
    38        additional_properties = {}
    39        for prop_name, prop_dict in d.items():
    40            additional_property = cast(List[float], prop_dict)
    41
    42            additional_properties[prop_name] = additional_property
    43
    44        explainability_create_config_json_body_feature_bounds.additional_properties = additional_properties
    45        return explainability_create_config_json_body_feature_bounds
    46
    47    @property
    48    def additional_keys(self) -> List[str]:
    49        return list(self.additional_properties.keys())
    50
    51    def __getitem__(self, key: str) -> List[float]:
    52        return self.additional_properties[key]
    53
    54    def __setitem__(self, key: str, value: List[float]) -> None:
    55        self.additional_properties[key] = value
    56
    57    def __delitem__(self, key: str) -> None:
    58        del self.additional_properties[key]
    59
    60    def __contains__(self, key: str) -> bool:
    61        return key in self.additional_properties

@attr.s(auto_attribs=True)
class ExplainabilityCreateConfigJsonBodyFeatureBounds: View Source

     8@attr.s(auto_attribs=True)
     9class ExplainabilityCreateConfigJsonBodyFeatureBounds:
    10    """ Calculated feature bounds
    11
    12    """
    13
    14    additional_properties: Dict[str, List[float]] = attr.ib(init=False, factory=dict)
    15
    16
    17    def to_dict(self) -> Dict[str, Any]:
    18
    19        field_dict: Dict[str, Any] = {}
    20        for prop_name, prop in self.additional_properties.items():
    21            field_dict[prop_name] = prop
    22
    23
    24
    25
    26        field_dict.update({
    27        })
    28
    29        return field_dict
    30
    31
    32
    33    @classmethod
    34    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    35        d = src_dict.copy()
    36        explainability_create_config_json_body_feature_bounds = cls(
    37        )
    38
    39        additional_properties = {}
    40        for prop_name, prop_dict in d.items():
    41            additional_property = cast(List[float], prop_dict)
    42
    43            additional_properties[prop_name] = additional_property
    44
    45        explainability_create_config_json_body_feature_bounds.additional_properties = additional_properties
    46        return explainability_create_config_json_body_feature_bounds
    47
    48    @property
    49    def additional_keys(self) -> List[str]:
    50        return list(self.additional_properties.keys())
    51
    52    def __getitem__(self, key: str) -> List[float]:
    53        return self.additional_properties[key]
    54
    55    def __setitem__(self, key: str, value: List[float]) -> None:
    56        self.additional_properties[key] = value
    57
    58    def __delitem__(self, key: str) -> None:
    59        del self.additional_properties[key]
    60
    61    def __contains__(self, key: str) -> bool:
    62        return key in self.additional_properties

Calculated feature bounds

ExplainabilityCreateConfigJsonBodyFeatureBounds() View Source

    2def __init__(self, ):
    3    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class ExplainabilityCreateConfigJsonBodyFeatureBounds.

def to_dict(self) -> Dict[str, Any]: View Source

    17    def to_dict(self) -> Dict[str, Any]:
    18
    19        field_dict: Dict[str, Any] = {}
    20        for prop_name, prop in self.additional_properties.items():
    21            field_dict[prop_name] = prop
    22
    23
    24
    25
    26        field_dict.update({
    27        })
    28
    29        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    33    @classmethod
    34    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    35        d = src_dict.copy()
    36        explainability_create_config_json_body_feature_bounds = cls(
    37        )
    38
    39        additional_properties = {}
    40        for prop_name, prop_dict in d.items():
    41            additional_property = cast(List[float], prop_dict)
    42
    43            additional_properties[prop_name] = additional_property
    44
    45        explainability_create_config_json_body_feature_bounds.additional_properties = additional_properties
    46        return explainability_create_config_json_body_feature_bounds

additional_keys: List[str]